@@ -8,6 +8,7 @@ from aioclustermanager.k8s.node_list import K8SNodeList
 from aioclustermanager.k8s.quota import K8SQuota
 from aioclustermanager.k8s.tf_job import K8STFJob
 from aioclustermanager.k8s.tf_job_list import K8STFJobList
+from aioclustermanager.k8s.scale import K8SScale
 
 import concurrent
 import json
@@ -45,8 +46,8 @@ GET_OPS = {
     'scale': '{scheme}://{endpoint}/apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale'  # noqa
 }
 
-PATCH_OPS = {
-    'scale': '{scheme}://{endpoint}/apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale'  # noqa
+PUT_OPS = {
+    'scale': ('{scheme}://{endpoint}/apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale', 'autoscaling/v1')  # noqa
 }
 
 POST_OPS = {
@@ -170,26 +171,19 @@ class K8SCaller(object):
         if result is None:
             return None
         else:
-            logger.warning(result)
             return result['status']['replicas']
 
     async def set_scale_deploy(self, namespace, name, scale):
-        url = PATCH_OPS['scale']
+        url, version = PUT_OPS['scale']
         url = url.format(
             namespace=namespace,
             name=name,
             endpoint=self.endpoint,
             scheme=self.scheme)
-        obj = [{
-            "op": "replace",
-            "path": "/spec/replicas",
-            "value": scale
-        }]
-        result = await self.patch(url, obj)
-        if result is None:
-            return None
-        else:
-            return result['spec']['replicas']
+
+        obj = K8SScale(namespace, name, scale)
+
+        return await self.put(url, version, obj.payload())
 
     async def get_job(self, namespace, name):
         url = GET_OPS['job']
@@ -253,28 +247,28 @@ class K8SCaller(object):
         async for logline in await self._watch_log(url, timeout=3660):
             yield logline
 
-    async def delete_job(self, namespace, name, wait=False):
+    async def delete_job(self, namespace, name, wait=False, purge=True):
         url, version = DELETE_OPS['job']
         url = url.format(
             namespace=namespace,
             name=name,
             endpoint=self.endpoint,
             scheme=self.scheme)
-        obj = K8SDelete()
+        obj = K8SDelete(purge)
         await self.delete(url, version, obj.payload())
         if wait:
             return await self.wait_deleted('job', namespace, name)
         return True
 
     async def delete_execution(self, namespace, job_id,
-                               execution_id, wait=False):
+                               execution_id, wait=False, purge=True):
         url, version = DELETE_OPS['execution']
         url = url.format(
             namespace=namespace,
             name=execution_id,
             endpoint=self.endpoint,
             scheme=self.scheme)
-        obj = K8SDelete()
+        obj = K8SDelete(purge)
         await self.delete(url, version, obj.payload())
         if wait:
             return await self.wait_deleted(
@@ -453,6 +447,23 @@ class K8SCaller(object):
                 raise Exception(
                     'Error calling k8s: %d - %s' % (resp.status, text))
 
+    async def put(self, url, version, payload):
+        payload['apiVersion'] = version
+        async with self.session.put(
+                url,
+                json=payload,
+                headers={
+                    'Accept': 'application/json'
+                },
+                ssl_context=self.ssl_context,
+                verify_ssl=self.verify) as resp:
+            if resp.status in [201, 200]:
+                return await resp.json()
+            else:
+                text = await resp.text()
+                raise Exception(
+                    'Error calling k8s: %d - %s' % (resp.status, text))
+
     async def post(self, url, version, payload):
         payload['apiVersion'] = version
         async with self.session.post(
